@@ -44,7 +44,7 @@ public:
   //! \brief get partitions
   //! \return partition list
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  const std::vector <partition>
+  std::vector <partition>
   get_partitions () const
   {
     return impl_->get_partitions ();
@@ -54,7 +54,7 @@ public:
   //! \brief get partition system entries
   //! \return entry list
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  const std::vector <entry>
+  std::vector <entry>
   get_entries () const
   {
     return impl_->get_entries ();
