@@ -20,13 +20,12 @@
 //! \file cookie.cc C++ API <i>mobius.model.cookie</i> class wrapper
 //! \author Eduardo Aguiar
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+#include <pymobius.h>
 #include "cookie.h"
 #include "case.h"
 #include "item.h"
 #include "profile.h"
 #include "module.h"
-#include "api.h"
-#include "api_datetime.h"
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 //! \brief Check if object type is <i>cookie</i>
@@ -132,7 +131,7 @@ tp_getter_name (model_cookie_o *self)
 
   try
     {
-      ret = PyString_FromString (self->obj->get_name ().c_str ());
+      ret = mobius::py::pystring_from_std_string (self->obj->get_name ());
     }
   catch (const std::exception& e)
     {
@@ -154,7 +153,7 @@ tp_getter_value (model_cookie_o *self)
 
   try
     {
-      ret = PyString_FromString (self->obj->get_value ().c_str ());
+      ret = mobius::py::pybytes_from_bytearray (self->obj->get_value ());
     }
   catch (const std::exception& e)
     {
@@ -176,7 +175,7 @@ tp_getter_domain (model_cookie_o *self)
 
   try
     {
-      ret = PyString_FromString (self->obj->get_domain ().c_str ());
+      ret = mobius::py::pystring_from_std_string (self->obj->get_domain ());
     }
   catch (const std::exception& e)
     {
@@ -203,7 +202,7 @@ tp_setter_domain (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!PyString_Check (value))
+  if (!mobius::py::pystring_check (value))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'domain' attribute");
       return -1;
@@ -212,7 +211,7 @@ tp_setter_domain (model_cookie_o *self, PyObject *value, void *)
   // Set domain attribute
   try
     {
-      self->obj->set_domain (PyString_AsString (value));
+      self->obj->set_domain (mobius::py::pystring_as_std_string (value));
     }
   catch (const std::exception& e)
     {
@@ -236,7 +235,7 @@ tp_getter_creation_time (model_cookie_o *self)
 
   try
     {
-      ret = PyDateTime_from_datetime (self->obj->get_creation_time ());
+      ret = mobius::py::pydatetime_from_datetime (self->obj->get_creation_time ());
     }
   catch (const std::exception& e)
     {
@@ -263,7 +262,7 @@ tp_setter_creation_time (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!check_PyDateTime (value) && (value != Py_None))
+  if (!mobius::py::pydatetime_check (value) && (value != Py_None))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'creation_time' attribute");
       return -1;
@@ -272,7 +271,7 @@ tp_setter_creation_time (model_cookie_o *self, PyObject *value, void *)
   // Set creation_time attribute
   try
     {
-      self->obj->set_creation_time (PyDateTime_as_datetime (value));
+      self->obj->set_creation_time (mobius::py::pydatetime_as_datetime (value));
     }
   catch (const std::exception& e)
     {
@@ -296,7 +295,7 @@ tp_getter_expiration_time (model_cookie_o *self)
 
   try
     {
-      ret = PyDateTime_from_datetime (self->obj->get_expiration_time ());
+      ret = mobius::py::pydatetime_from_datetime (self->obj->get_expiration_time ());
     }
   catch (const std::exception& e)
     {
@@ -323,7 +322,7 @@ tp_setter_expiration_time (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!check_PyDateTime (value) && (value != Py_None))
+  if (!mobius::py::pydatetime_check (value) && (value != Py_None))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'expiration_time' attribute");
       return -1;
@@ -332,7 +331,7 @@ tp_setter_expiration_time (model_cookie_o *self, PyObject *value, void *)
   // Set expiration_time attribute
   try
     {
-      self->obj->set_expiration_time (PyDateTime_as_datetime (value));
+      self->obj->set_expiration_time (mobius::py::pydatetime_as_datetime (value));
     }
   catch (const std::exception& e)
     {
@@ -356,7 +355,7 @@ tp_getter_last_access_time (model_cookie_o *self)
 
   try
     {
-      ret = PyDateTime_from_datetime (self->obj->get_last_access_time ());
+      ret = mobius::py::pydatetime_from_datetime (self->obj->get_last_access_time ());
     }
   catch (const std::exception& e)
     {
@@ -383,7 +382,7 @@ tp_setter_last_access_time (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!check_PyDateTime (value) && (value != Py_None))
+  if (!mobius::py::pydatetime_check (value) && (value != Py_None))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'last_access_time' attribute");
       return -1;
@@ -392,7 +391,7 @@ tp_setter_last_access_time (model_cookie_o *self, PyObject *value, void *)
   // Set last_access_time attribute
   try
     {
-      self->obj->set_last_access_time (PyDateTime_as_datetime (value));
+      self->obj->set_last_access_time (mobius::py::pydatetime_as_datetime (value));
     }
   catch (const std::exception& e)
     {
@@ -416,7 +415,7 @@ tp_getter_evidence_path (model_cookie_o *self)
 
   try
     {
-      ret = PyString_FromString (self->obj->get_evidence_path ().c_str ());
+      ret = mobius::py::pystring_from_std_string (self->obj->get_evidence_path ());
     }
   catch (const std::exception& e)
     {
@@ -443,7 +442,7 @@ tp_setter_evidence_path (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!PyString_Check (value))
+  if (!mobius::py::pystring_check (value))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'evidence_path' attribute");
       return -1;
@@ -452,7 +451,7 @@ tp_setter_evidence_path (model_cookie_o *self, PyObject *value, void *)
   // Set evidence_path attribute
   try
     {
-      self->obj->set_evidence_path (PyString_AsString (value));
+      self->obj->set_evidence_path (mobius::py::pystring_as_std_string (value));
     }
   catch (const std::exception& e)
     {
@@ -476,7 +475,7 @@ tp_getter_is_deleted (model_cookie_o *self)
 
   try
     {
-      ret = PyBool_FromLong (self->obj->is_deleted ());
+      ret = mobius::py::pybool_from_bool (self->obj->is_deleted ());
     }
   catch (const std::exception& e)
     {
@@ -503,7 +502,7 @@ tp_setter_is_deleted (model_cookie_o *self, PyObject *value, void *)
     }
 
   // Check argument type
-  if (!PyBool_Check (value))
+  if (!mobius::py::pybool_check (value))
     {
       PyErr_SetString (PyExc_TypeError, "Invalid type for 'is_deleted' attribute");
       return -1;
@@ -536,7 +535,7 @@ tp_getter_is_encrypted (model_cookie_o *self)
 
   try
     {
-      ret = PyBool_FromLong (self->obj->is_encrypted ());
+      ret = mobius::py::pybool_from_bool (self->obj->is_encrypted ());
     }
   catch (const std::exception& e)
     {
